@@ -1,3 +1,6 @@
+import sys
+from typing import List
+
 from inspector_commons.bridge.base import Bridge, traceback
 from inspector_commons.bridge.mixin import DatabaseMixin
 from inspector_commons.driver_windows import (
@@ -16,7 +19,7 @@ class WindowsBridge(DatabaseMixin, Bridge):
         self.windows_driver = WindowsDriver()
 
     @traceback
-    def pick(self, active_window: str) -> WindowsLocator:
+    def pick(self, active_window: str) -> List[WindowsLocator]:
         self.logger.info("Picking windows locator from=%s", active_window)
         return self.windows_driver.listen(active_window)
 
@@ -34,3 +37,19 @@ class WindowsBridge(DatabaseMixin, Bridge):
     def focus(self, active_window: str, value: str) -> None:
         self.logger.info("Focus element")
         self.windows_driver.focus(active_window, value)
+
+    @traceback
+    def save(self, name, locator):
+        self.ctx.database.load()
+        return super().save(name, locator)
+
+    def set_window_height(self, height):
+        local_width = self.window.DEFAULTS["width"]
+        local_width = local_width + 20 if sys.platform == "win32" else local_width
+        local_height = height + 20 if sys.platform == "win32" else height
+        self.logger.debug(
+            "Setting the window to: %s (height) x %s (width)",
+            local_height,
+            local_width,
+        )
+        self.window.resize(local_width, local_height)
