@@ -3,7 +3,7 @@ import logging
 from dataclasses import dataclass
 from io import BytesIO
 from queue import Empty, Queue
-from typing import Dict, List, Tuple, Union
+from typing import Dict, List, Optional, Tuple, Union
 
 try:
     import uiautomation as auto  # type: ignore # pylint: disable=import-error, useless-suppression # noqa: E501
@@ -19,14 +19,14 @@ try:
         WindowsElements,
     )
     from RPA.core.windows.context import ElementNotFound  # type: ignore
-except ImportError as exc:
+except Exception as exc:  # type: ignore # pylint: disable=broad-except, useless-suppression # noqa: E501
     print("Importing the WIN32 packages failed. Will continue. Exception: %s", exc)
 
 from RPA.core.geometry import Region  # type: ignore
 
 LOCATOR_VERSION = 1.0
 
-PICK_TIMEOUT = 60
+PICK_TIMEOUT = 30
 
 WindowsLocatorProperties = Dict[str, str]
 WindowsLocator = Dict[str, WindowsLocatorProperties]
@@ -83,7 +83,8 @@ class WindowsDriver:
     def _construct_locator(
         self,
         element,
-    ) -> WindowsLocator:
+    ) -> List[WindowsLocator]:
+        properties_list = []
         locator_path: str = element["locator"]
         control: auto.Control = element["control"]
         window_name: str = element["top"]
@@ -92,45 +93,64 @@ class WindowsDriver:
 
         name = control.Name or "WindowsLocator"
 
-        properties = {
-            "window": self._active_window,
-            "strategy": "WindowsLocator",
-            "value": locator_path,
-            "version": LOCATOR_VERSION,
-        }
+        locator_paths = [
+            part
+            for part in locator_path.split(" and ")
+            for prop in ["name:", "id:"]
+            if part.lower().startswith(prop)
+        ]
 
-        if hasattr(control, "BoundingRectangle"):
-            try:
-                properties["screenshot"] = Rectangle.from_control(
-                    control
-                ).get_screenshot()
-            except AttributeError as err:
-                self.logger.error("Failed to get locator screenshot=%r", err)
+        for loc in locator_paths:
+            properties = {
+                "window": self._active_window,
+                "strategy": "WindowsLocator",
+                "value": loc,
+                "version": LOCATOR_VERSION,
+                "name": name,
+                "type": "windows",
+                "kind": "locator",
+            }
 
-        return {name: properties}
+            self.logger.info("Add properties to list=%s", properties)
+
+            if hasattr(control, "BoundingRectangle"):
+                try:
+                    properties["screenshot"] = Rectangle.from_control(
+                        control
+                    ).get_screenshot()
+                except AttributeError as err:
+                    self.logger.error("Failed to get locator screenshot=%r", err)
+            properties_list.append(properties)
+        return properties_list
 
     def _on_click(
         self,
         x_coord: int,
         y_coord: int,
-        element,  # pylint: disable=unused-argument
+        mouse_button,
         pressed: bool,
     ) -> None:
-        self.logger.debug("Element clicked (%s) at=%s,%s", pressed, x_coord, y_coord)
-
-        locator = {}
+        self.logger.debug(
+            "Element clicked (%s) with button=%s at=%s,%s",
+            pressed,
+            mouse_button,
+            x_coord,
+            y_coord,
+        )
 
         try:
             elements: List[RecordElement] = []
-            ElementInspector.inspect_element(action="", recording=elements)
-            locator = self._construct_locator(elements[0])
+            ElementInspector.inspect_element(
+                action="", recording=elements, verbose=True
+            )
+            locators = self._construct_locator(elements[0])
         except (ValueError, IndexError) as err:
             self.logger.error(err)
-        except WindowMismatch as err:
-            self.logger.info(err)
             return
-
-        self.queue.put(locator)
+        except WindowMismatch as err:
+            self.logger.error(err)
+            return
+        self.queue.put(locators, block=False, timeout=PICK_TIMEOUT)
 
     @classmethod
     def _find_all_top_level_window(cls) -> List:
@@ -149,22 +169,30 @@ class WindowsDriver:
         else:
             self.logger.error("Could not focus window=%s", active_window)
 
-    def listen(self, active_window: str):
+    def get_window_control(self, window: str) -> Optional[auto.Control]:
+        windows = self._find_all_top_level_window()
+        for win in windows:
+            if hasattr(win, "Name") and win.Name == window:
+                return win
+        self.logger.error("Could not get window=%s", window)
+        return None
+
+    def listen(self, active_window: str) -> List[WindowsLocator]:
         with auto.UIAutomationInitializerInThread(debug=True):
             self.logger.info(
                 "Start listening for mouse click in window=%s", active_window
             )
             self._focus_active_window(active_window)
-            locator = {}
+            locators: List[WindowsLocator] = []
             listener = Listener(on_click=self._on_click)
             try:
                 listener.start()
-                locator = self.queue.get(block=True, timeout=PICK_TIMEOUT)
+                locators = self.queue.get(block=True, timeout=PICK_TIMEOUT)
             except Empty:
                 self.logger.info("Locator selection timeout")
             finally:
                 listener.stop()
-        return locator
+        return locators
 
     def validate(self, window: str, value: str) -> MatchedWindowsLocators:
         self.logger.info("Validate=%s, %s", window, value)
